@@ -1,3 +1,3 @@
 """Module providing __init__ functionality."""
 from matrice.utils import dependencies_check
-dependencies_check(["requests", "Pillow"])
+dependencies_check(["requests", "Pillow","aiohttp"])
