@@ -23,7 +23,9 @@ import cv2
 import numpy as np
 #import torch
 import re
-
+from collections import Counter
+#from turbojpeg import TurboJPEG, TJPF_RGB
+os.environ["ORT_LOG_SEVERITY_LEVEL"] = "3"
 # Fast license-plate OCR (replaces EasyOCR)
 # Attempt to import fast_plate_ocr; fall back to a stub if unavailable
 try:
@@ -53,7 +55,7 @@ class LicensePlateMonitorConfig(BaseConfig):
     smoothing_window_size: int = 20
     smoothing_cooldown_frames: int = 5
     smoothing_confidence_range_factor: float = 0.5
-    confidence_threshold: float = 0.565
+    confidence_threshold: float = 0.5
     frame_skip: int = 1
     fps: Optional[float] = None
     bbox_format: str = "auto"
@@ -63,6 +65,7 @@ class LicensePlateMonitorConfig(BaseConfig):
     index_to_category: Optional[Dict[int, str]] = field(default_factory=lambda: {0: "license_plate"})
     language: List[str] = field(default_factory=lambda: ['en'])
     country: str = field(default_factory=lambda: 'us')
+    ocr_mode:str = field(default_factory=lambda: "numeric") # "alphanumeric" or "numeric" or "alphabetic"
 
     def validate(self) -> List[str]:
         """Validate configuration parameters."""
@@ -113,6 +116,8 @@ class LicensePlateMonitorUseCase(BaseProcessor):
         self._tracked_plate_texts: Dict[Any, str] = {}
         # Containers for text stability & uniqueness
         self._unique_plate_texts: Dict[str, str] = {}  # cleaned_text -> original (longest)
+        # Helper dictionary to keep history of plate texts per track
+        self.helper: Dict[Any, List[str]] = {}
         self.image_preprocessor = ImagePreprocessor()
         # Fast OCR model (shared across instances)
         if LicensePlateMonitorUseCase._ocr_model is None:
@@ -133,7 +138,9 @@ class LicensePlateMonitorUseCase(BaseProcessor):
         # number of consecutive frames a plate must appear to be considered "stable"
         self._stable_frames_required = 3
         self._non_alnum_regex = re.compile(r"[^A-Za-z0-9]+")
-        self._ocr_mode = "numeric" # "alphanumeric" or "numeric" or "alphabetic"
+        self._ocr_mode = None
+        #self.jpeg = TurboJPEG()
+        
 
     def reset_tracker(self) -> None:
         """Reset the advanced tracker instance."""
@@ -150,6 +157,7 @@ class LicensePlateMonitorUseCase(BaseProcessor):
         self._global_frame_offset = 0
         self._text_history = {}
         self._unique_plate_texts = {}
+        self.helper = {}
         self.logger.info("Plate tracking state reset")
 
     def reset_all_tracking(self) -> None:
@@ -190,7 +198,7 @@ class LicensePlateMonitorUseCase(BaseProcessor):
             input_format = match_results_structure(data)
             context.input_format = input_format
             context.confidence_threshold = config.confidence_threshold
-            
+            self._ocr_mode = config.ocr_mode
             self.logger.info(f"Processing license plate monitoring with format: {input_format.value}")
             
             # Step 1: Apply confidence filtering 1
@@ -230,9 +238,9 @@ class LicensePlateMonitorUseCase(BaseProcessor):
                 from ..advanced_tracker.config import TrackerConfig
                 if self.tracker is None:
                     tracker_config = TrackerConfig(
-                        track_high_thresh=float(config.confidence_threshold-0.1),
-                        track_low_thresh=max(0.05, float(config.confidence_threshold) / 2),
-                        new_track_thresh=float(config.confidence_threshold-0.1)
+                        track_high_thresh=float(config.confidence_threshold),
+                        track_low_thresh=0.25,
+                        new_track_thresh=float(config.confidence_threshold)
                     )
                     self.tracker = AdvancedTracker(tracker_config)
                     self.logger.info(f"Initialized AdvancedTracker with thresholds: high={tracker_config.track_high_thresh}, "
@@ -336,12 +344,13 @@ class LicensePlateMonitorUseCase(BaseProcessor):
     def _analyze_ocr_in_image(self, data: Any, image_bytes: bytes, config: LicensePlateMonitorConfig) -> List[Dict[str, Any]]:
         """Analyze OCR in a single image."""
         image_array = np.frombuffer(image_bytes, np.uint8)
-        image = cv2.imdecode(image_array, cv2.IMREAD_UNCHANGED)
+        image = cv2.imdecode(image_array, cv2.IMREAD_COLOR)
+        #image = self.jpeg.decode(image_bytes, pixel_format=TJPF_RGB) #cv2.imdecode(image_array, cv2.IMREAD_UNCHANGED)
         
         if image is None:
             raise RuntimeError("Failed to decode image from bytes")
         
-        rgb_image = image #cv2.cvtColor(image, cv2.COLOR_BGR2RGB)
+        rgb_image = cv2.cvtColor(image, cv2.COLOR_BGR2RGB)
         ocr_analysis = []
         detections = self._get_frame_detections(data, "0")
 
@@ -808,38 +817,115 @@ class LicensePlateMonitorUseCase(BaseProcessor):
             self._current_frame_track_ids[cat].add(canonical_id)
 
     def _update_plate_texts(self, detections: List[Dict]):
-        """Update set of seen plate texts and track the longest plate_text per track_id."""
+        """Update plate text history, compute dominant text per track and merge duplicate tracks.
+
+        For each ``track_id`` we keep a running list (``self.helper``) of all recognised
+        plate texts *in the order they were seen*.  After every frame we:
+
+        1.  Derive the **dominant** plate text for every track by looking only at the
+            **last 50 %** of the observations for that track and selecting the most
+            frequent value.  When multiple values are tied we take the one that
+            appears **latest** in the observation window (i.e. closest to the
+            current frame).
+        2.  Merge different ``track_id``\ s that resolve to the *same* dominant
+            plate text (perfect textual match).  The first track_id that produced
+            the text becomes the canonical id; all other tracks are remapped to
+            this id for the remainder of the processing.
+
+        The method updates the following internal structures so that subsequent
+        counting/summary steps see the correct data:
+        - ``self._tracked_plate_texts``   →  mapping of canonical *track_id → text*
+        - ``self._unique_plate_texts``    →  mapping of *cleaned_text → longest_raw*
+        - ``detections`` list (in-place)  →  each detection now carries the
+          canonical ``track_id`` and the dominant ``plate_text``.
+        """
+        
+        def _select_dominant(text_list: List[str]) -> str:
+            """Return dominant element from the last 50 % of *text_list*.
+
+            When there is a tie we return the **latest** occurring element among
+            the tied ones.
+            """
+            if not text_list:
+                return ""
+            half_idx = len(text_list) // 2  # start of the last 50 %
+            window = text_list[half_idx:]
+            counts = Counter(window)
+            max_freq = max(counts.values())
+            # All items with max frequency
+            candidates = {txt for txt, cnt in counts.items() if cnt == max_freq}
+            if len(candidates) == 1:
+                return next(iter(candidates))
+            # Tie-breaker – iterate backwards to find latest candidate
+            for txt in reversed(window):
+                if txt in candidates:
+                    return txt
+            # Fallback (should not happen)
+            return window[-1]
+
+        # ------------------------------------------------------------------
+        # 1)  Collect plate texts observed in this frame --------------------
+        # ------------------------------------------------------------------
         for det in detections:
-            text = det.get('plate_text')
-            track_id = det.get('track_id')
-            if text and track_id is not None:
-                # Clean text again to guarantee consistency
-                text = self._clean_text(text)
-                if len(text) < self._min_plate_len:
-                    continue  # Too short to be a valid plate
+            raw_text = det.get("plate_text") or ""
+            if not raw_text:
+                continue
+            cleaned = self._clean_text(raw_text)
+            if len(cleaned) < self._min_plate_len:
+                # Too short – ignore (length & alphanumeric checks stay intact)
+                continue
+            track_id = det.get("track_id")
+            if track_id is None:
+                continue
+            # Keep full raw_text – consumers may prefer longest raw variant
+            self.helper.setdefault(track_id, []).append(raw_text)
 
-                # ----------------------------------------------------------
-                # Update consecutive frame appearance counter
-                # ----------------------------------------------------------
-                self._text_history[text] = self._text_history.get(text, 0) + 1
+        # ------------------------------------------------------------------
+        # 2)  Compute dominant text per track --------------------------------
+        # ------------------------------------------------------------------
+        track_to_text: Dict[Any, str] = {}
+        for t_id, text_list in self.helper.items():
+            dominant_raw = _select_dominant(text_list)
+            if dominant_raw:
+                track_to_text[t_id] = dominant_raw
 
-                # Accept plate as stable only after N consecutive frames
-                if self._text_history[text] >= self._stable_frames_required:
-                    # Track longest string variant per track_id
-                    current_text = self._tracked_plate_texts.get(track_id, '')
-                    if len(text) > len(current_text):
-                        self._tracked_plate_texts[track_id] = text
-                    # Maintain global unique mapping (cleaned -> original longest)
-                    longest_variant = self._unique_plate_texts.get(text, '')
-                    if len(text) > len(longest_variant):
-                        self._unique_plate_texts[text] = text
-                   # self.logger.debug(f"Stable plate confirmed: {text} (track_id={track_id})")
+        # ------------------------------------------------------------------
+        # 3)  Merge tracks that share the same dominant text -----------------
+        # ------------------------------------------------------------------
+        text_to_canonical: Dict[str, Any] = {}
+        track_id_remap: Dict[Any, Any] = {}
+        for t_id, text in track_to_text.items():
+            cleaned = self._clean_text(text)
+            if cleaned in text_to_canonical:
+                # Duplicate plate → map to existing canonical id
+                canonical_id = text_to_canonical[cleaned]
+                track_id_remap[t_id] = canonical_id
+            else:
+                text_to_canonical[cleaned] = t_id
 
-        # Reset counters for texts not seen in this frame
-        current_frame_texts = {self._clean_text(det.get('plate_text', '')) for det in detections if det.get('plate_text')}
-        for t in list(self._text_history.keys()):
-            if t not in current_frame_texts:
-                self._text_history[t] = 0
+        # Update internal dictionaries -------------------------------------
+        self._tracked_plate_texts = {track_id_remap.get(t_id, t_id): txt for t_id, txt in track_to_text.items()}
+        # Maintain unique cleaned → longest_raw mapping
+        for raw in track_to_text.values():
+            cleaned = self._clean_text(raw)
+            longest = self._unique_plate_texts.get(cleaned, "")
+            if len(raw) > len(longest):
+                self._unique_plate_texts[cleaned] = raw
+
+        # ------------------------------------------------------------------
+        # 4)  Apply remapping & dominant text to current detections ----------
+        # ------------------------------------------------------------------
+        for det in detections:
+            track_id = det.get("track_id")
+            if track_id is None:
+                continue
+            canonical_id = track_id_remap.get(track_id, track_id)
+            det["track_id"] = canonical_id
+            dominant_text = self._tracked_plate_texts.get(canonical_id, det.get("plate_text"))
+            det["plate_text"] = dominant_text
+
+        # No need for consecutive-frame stability counters any more – remove
+        self._text_history = {}
 
     def get_total_counts(self):
         """Return total unique license plate texts encountered so far."""
